@@ -10,7 +10,7 @@ use overload(
     '&{}' => sub {
         my $self = shift;
         my @caller = caller(0);
-        update_mask($caller[1], $caller[2], '*', {restart => 1, stop => 1, 3 => 'CONTINUE'});
+        update_mask($caller[1], $caller[2], '*', {restart => 1, pause => 1, 3 => 'CONTINUE'});
         my $out = sub { $self->iterate(@_) };
         set_sub_name(__PACKAGE__ . '::iterator', $out)
             if CAN_SET_SUB_NAME();
@@ -266,7 +266,7 @@ sub _really_run_primary {
         $self->runner->run(unit => $_, args => $self->{+ARGS}) for @$primary
     }
     else {
-        BEGIN { update_mask(__FILE__, __LINE__ + 1, '*', {stop => 1, restart => 1, shift => 1}) }
+        BEGIN { update_mask(__FILE__, __LINE__ + 1, '*', {pause => 1, restart => 1, shift => 1}) }
         $primary->(@{$self->{+ARGS}});
     }
 }
